Method: ActiveEntity::AttributeMethods#attribute_for_inspect

Defined in:
lib/active_entity/attribute_methods.rb

#attribute_for_inspect(attr_name) ⇒ Object

Returns an #inspect-like string for the value of the attribute attr_name. String attributes are truncated up to 50 characters, Date and Time attributes are returned in the :db format. Other attributes return the value of #inspect without modification.

person = Person.create!(name: 'David Heinemeier Hansson ' * 3)

person.attribute_for_inspect(:name)
# => "\"David Heinemeier Hansson David Heinemeier Hansson ...\""

person.attribute_for_inspect(:created_at)
# => "\"2012-10-22 00:15:07\""

person.attribute_for_inspect(:tag_ids)
# => "[1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11]"


742
743
744
745
746
# File 'lib/active_entity/attribute_methods.rb', line 742

def attribute_for_inspect(attr_name)
  attr_name = attr_name.to_s
  value = _read_attribute(attr_name)
  format_for_inspect(value)
end