Method: ActiveEntity::Validations::ClassMethods#validates_absence_of

Defined in:
lib/active_entity/validations/absence.rb

#validates_absence_of(*attr_names) ⇒ Object

Validates that the specified attributes are not present (as defined by Object#present?). If the attribute is an association, the associated object is considered absent if it was marked for destruction.

See ActiveModel::Validations::HelperMethods.validates_absence_of for more information.



20
21
22
# File 'lib/active_entity/validations/absence.rb', line 20

def validates_absence_of(*attr_names)
  validates_with AbsenceValidator, _merge_attributes(attr_names)
end